@@ -2,7 +2,7 @@
 
 cd `dirname $0`
 pwdir=`pwd`
-for a in `find src tools -name "autogen.sh" |sort`; do
+for a in `find src tools autodoc -name "autogen.sh" |sort`; do
   dir=`dirname $a`
   echo "Running autogen in '$dir'"
   cd $dir >/dev/null 2>&1
@@ -10,4 +10,4 @@ for a in `find src tools -name "autogen.sh" |sort`; do
   cd $pwdir >/dev/null 2>&1
 done  
 
-autoconf >/dev/null 2>&1
\ No newline at end of file
+autoconf >/dev/null 2>&1
