@@ -23,8 +23,7 @@
 
 class ThemedConfig {
 
-    constant cvs_version = "$Id: mainconfig_themeable.h,v 1.7.2.3 2005/01/03 17:01:16 kiwi Exp $";
-
+    constant cvs_version = "$Id: mainconfig_themeable.h,v 1.14.2.1 2005/01/03 17:03:02 kiwi Exp $";
     object s;
     string datadir, themename;
     void create( void|string schemename, string _datadir ) {
@@ -104,7 +103,7 @@ class ThemedConfig {
 		q+=p+"/";
 		res +=
 		    ({ "<a href=\""+q+"?"+bar+++"\"><font color='" + s->html_colour( "titlefg" ) + "'>"+
-                       dn(find_node(http_decode_string(q[..strlen(q)-2])))+
+                       dn(find_node(_Roxen.http_decode_string(q[..strlen(q)-2])))+
                        "</font></a>" });
 	    }
 	    return (res * " -&gt; ");
@@ -132,57 +131,64 @@ class ThemedConfig {
     }
 
     object tab_0() {
+	object i;
 	array fg_rgb = s->rgb_colour( "titlefg" );
         array bg_rgb = s->rgb_colour( "titlebg" );
-	object i = Image.Image( 24, 24, @fg_rgb);
+	i = Image.Image( 24, 24, @fg_rgb);
         return i;
     }
 
     object tab_1() {
+	object i;
 	array fg_rgb = s->rgb_colour( "titlefg" );
         array bg_rgb = s->rgb_colour( "titlebg" );
-	object i = Image.Image( 24, 24, @fg_rgb);
-	i = circlefill( i, 0, 24, 23, @bg_rgb, 255 );
+	i = Image.Image( 24, 24, @fg_rgb);
+	i = circlefill( i, 0, 24, 23, @bg_rgb, 0);
         return i;
     }
 
     object tab_2() {
+        object i;
 	array fg_rgb = s->rgb_colour( "titlefg" );
         array bg_rgb = s->rgb_colour( "titlebg" );
-	object i = Image.Image( 24, 24, @bg_rgb );
-	i = circlefill( i, 0, 24, 24, @fg_rgb, 255 );
-	i = circlefill( i, 0, 24, 23, @bg_rgb, 255 );
+	i = Image.Image( 24, 24, @bg_rgb );
+	i = circlefill( i, 0, 24, 24, @fg_rgb, 0);
+	i = circlefill( i, 0, 24, 23, @bg_rgb, 0);
         return i;
     }
 
     object tab_3() {
+	object i;
 	array fg_rgb = s->rgb_colour( "titlefg" );
         array bg_rgb = s->rgb_colour( "titlebg" );
-	object i = Image.Image( 24, 24, @bg_rgb);
-	i = circlefill( i, 0, 24, 24, @fg_rgb, 255 );
+	i = Image.Image( 24, 24, @bg_rgb);
+	i = circlefill( i, 0, 24, 24, @fg_rgb, 0);
         return i;
     }
 
     object tab_4() {
+	object i;
 	array fg_rgb = s->rgb_colour( "titlefg" );
         array bg_rgb = s->rgb_colour( "titlebg" );
-	object i = Image.Image( 24, 24, @bg_rgb);
-	i = circlefill( i, 0, 24, 24, @fg_rgb, 255 );
+        i = Image.Image( 24, 24, @bg_rgb);
+	i = circlefill( i, 0, 24, 24, @fg_rgb, 0);
         i->line( 0, 0, 24, 0, @fg_rgb );
         return i;
     }
 
     object tab_5() {
+	object i;
 	array fg_rgb = s->rgb_colour( "titlefg" );
         array bg_rgb = s->rgb_colour( "titlebg" );
-	object i = Image.Image( 24, 24, @bg_rgb);
-	i = circlefill( i, 0, 24, 24, @fg_rgb, 255 );
-	i = circlefill( i, 0, 24, 23, @bg_rgb, 255 );
+	i = Image.Image( 24, 24, @bg_rgb);
+	i = circlefill( i, 0, 24, 24, @fg_rgb, 0);
+	i = circlefill( i, 0, 24, 23, @bg_rgb, 0);
 	i->line( 0, 0, 24, 0, @fg_rgb );
         return i;
     }
 
     object logo() {
+	object i;
 	array fg_rgb = s->rgb_colour( "titlefg" );
 	array bg_rgb = s->rgb_colour( "titlebg" );
 	object text = Image.PNM.decode(Stdio.read_file(datadir+"/cif_logo_txt.pnm"));
@@ -201,13 +207,13 @@ class ThemedConfig {
 			   _ysize,
 			   _ysize,
 			   @fg_rgb,
-			   255 );
+			   0);
 	back = circlefill( back,
 			   ( xsize + ysize ),
 			   0,
 			   _ysize,
 			   @fg_rgb,
-			   255 );
+			   0);
 	// This is a hack to fix the bug in circlefill();
 	back->line( back->xsize() - _ysize,
 		    0,
@@ -224,7 +230,6 @@ class ThemedConfig {
 			  text,
 			  ( ( back->xsize() - text->xsize() ) / 2 ),
 			  ( ( back->ysize() - text->ysize() ) / 2 ) );
-	/* Stdio.write_file("/tmp/image.gif", Image.GIF.encode(back)); */
         return back;
     }
 
