@@ -1,4 +1,4 @@
-// $Id: module.h,v 1.12.2.1 2002/03/25 15:14:04 kiwi Exp $
+// $Id: module.h,v 1.19 2003/03/04 20:36:50 hww3 Exp $
 #ifndef CAUDIUM_MODULE_H
 #define CAUDIUM_MODULE_H
 
@@ -37,7 +37,8 @@
 
 #define TYPE_CUSTOM          20
 #define TYPE_NODE            21
-#define	TYPE_EXISTING_FILE   22
+
+#define TYPE_EXISTING_FILE   22
 
 
 /* Variable indexes */
@@ -80,6 +81,9 @@
 #define MODULE_LOGGER            (1<<12)
 #define MODULE_FILTER            (1<<13)
 
+// Modules there are Caudium Specific API. Using them on a non Caudium
+// server is not supported by Roxen 1.3
+
 // This module type is called before request caching is done.
 // Used for virtual hosting that changes the virtual server (to fix caching)
 // and can also be used to build a custom cache key.
@@ -89,7 +93,8 @@
 #define MODULE_PROVIDER		 (1<<15)
 // The module implements a protocol.
 #define MODULE_PROTOCOL          (1<<16)
-
+// The module that handle error conditions (404, 500, etc..)
+#define MODULE_ERROR             (1<<17)
 
 // Flags.
 #define MODULE_SECURITY          (1<<29)
@@ -103,6 +108,7 @@
 #define MOD_ACCEPT_USER	6
 #define MOD_ACCEPT_PROXY_USER	7
 #define MOD_USER_SECLEVEL 8
+#define MOD_ACCEPT_GROUP 9
 
 #define DEFFONT(X,Y,Z,Q) \
 defvar((X)+"_font", (Y), (Z)+": font", TYPE_FONT, (Q));\
@@ -114,7 +120,8 @@ defvar((X)+"_slant", "plain", (Z)+": slant", TYPE_STRING_LIST, "", ({"italic","p
 #define NOCACHE() id->misc->cacheable=0
 #endif
 
-
-
-
+#define CAUDIUM_CACHE 1
+#define GET_CACHE() caudium->cache_manager->get_cache(this)
+// #define module_cache caudium->cache_manager->get_cache(this_object())
+// #define mc caudium->cache_manager->get_cache(this_object())
 
