@@ -1,5 +1,5 @@
 /* -*- Pike -*-
- * $Id: performance.h,v 1.10.2.2 2003/07/24 09:10:05 kiwi Exp $
+ * $Id: performance.h,v 1.18 2003/12/19 23:36:08 grendel Exp $
  *
  * Performance related defines. Also used to enable/disable Roxen
  * compat stuff that's disable for performance reasons.
@@ -121,15 +121,12 @@
 #undef API_COMPAT
 
 /*
- * Caudium 1.2 has a new error handler that allow you to create more
- * sexy error handler that the one used in Caudium 1.0 or Roxen 1.3.xx.
- * Because of XML-Compliant Parser is based on Pike's Parser.HTML that
- * has the main problem to fails to parse so HTML standart tags and/or
- * comment, sometime a 404 error is break the parser and give a 500 error
- * (internal server error) when XML-Compliant parser is used.
+ * The maximum body size the server should read upon a post
+ * request. -1 means unlimited and 0 means the body is completely
+ * ignored. The default value should be a reasonable value.
  */
-#ifndef DISABLE_NEW404
-# define ENABLE_NEW404
+#ifndef POST_MAX_BODY_SIZE
+#define POST_MAX_BODY_SIZE 1024*64
 #endif
 
 /*
@@ -140,4 +137,31 @@
  */
 #undef LOAD_CONFIGS_STARTUP
 
+
+/*
+ * Use spider.parse_html() and spider.parse_html_lines() instead
+ * of using Parse.HTML. Se this if you have some issues with this
+ * new routine. And don't forget to open a bug at our bug
+ * database : http://caudium.net/community/bugtraq.rxml
+ */
+#undef OLD_SPIDER
+
+/*
+ * Compare results between old spider and Parse.HTML return.
+ * Used only if OLD_SPIDER is not set.
+ */
+#define COMPARE_SPIDER
+
+/*
+ * Setting this will stop warnings in Caudium logfile about
+ * API compatibility issues.
+ *
+ * This not set because this can help developpers to make
+ * more up to date modules and code, but it can slow down
+ * a bit Caudium because of heavy usage of backtrace() pike
+ * function to help find in which file and which line the 
+ * compat API was called.
+ */
+#undef SILENT_COMPAT
+
 #endif
