@@ -18,11 +18,11 @@
  *
  */
 /*
- * $Id: caudium.c,v 1.144.2.13 2006/09/19 18:35:53 kiwi Exp $
+ * $Id: caudium.c,v 1.144.2.15 2007/02/27 08:30:44 bertrand Exp $
  */
 
 #include "global.h"
-RCSID("$Id: caudium.c,v 1.144.2.13 2006/09/19 18:35:53 kiwi Exp $");
+RCSID("$Id: caudium.c,v 1.144.2.15 2007/02/27 08:30:44 bertrand Exp $");
 #include "caudium_util.h"
 #include "caudium_machine.h"
 #include "entparse.h"
@@ -87,7 +87,7 @@ static_strings strs;
 /*
 **! file: Caudium/caudium.c
 **!  Caudium specific classes and functions.
-**! cvs_version: $Id: caudium.c,v 1.144.2.13 2006/09/19 18:35:53 kiwi Exp $
+**! cvs_version: $Id: caudium.c,v 1.144.2.15 2007/02/27 08:30:44 bertrand Exp $
 */
 
 /*
@@ -1066,14 +1066,15 @@ static void f_parse_query_string( INT32 args )
 
           if (!valulen) {
             /* valueless, add the name to the multiset */
-            sval.type = T_STRING;
-            sval.u.string = make_shared_binary_string(name, namelen);
-            if (!sval.u.string)
+            skey.type = T_STRING;
+            // This overrides url_decode(), a few lines before
+            //skey.u.string = make_shared_binary_string(name, namelen);
+            if (!skey.u.string)
               Pike_error("Out of memory.\n");
-            multiset_insert(emptyvars, &sval);
+            multiset_insert(emptyvars, &skey);
 
             free_svalue(&skey);
-            free_svalue(&sval);
+//            free_svalue(&sval);
             
             name = ptr + 1;
             equal = NULL;
