@@ -21,7 +21,7 @@
 /* This file should be included by ALL source code. It includes various
  * stuff to maintain source code compatibility between Pike versions.
  *
- * $Id: caudium_util.h,v 1.9 2001/07/16 20:40:27 neotron Exp $
+ * $Id: caudium_util.h,v 1.13 2004/02/26 23:58:51 grendel Exp $
  */
  
 /* Standard Pike include files. */
@@ -36,7 +36,6 @@
 #include "object.h"
 #include "pike_macros.h"
 #include "pike_types.h"
-#include "program.h"
 #include "stralloc.h"
 #include "svalue.h"
 #include "threads.h"
@@ -87,3 +86,30 @@
 #ifndef ARG
 #define ARG(_n_) Pike_sp[-((args - _n_) + 1)]
 #endif
+
+/*
+ * This allow run a module using dmalloc library http://www.dmalloc.org/
+ */
+#ifdef WITH_DMALLOC
+# include <dmalloc.h>
+#endif
+
+#ifdef HAVE_ALLOCA
+#define USE_ALLOCA 1
+#endif
+
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__APPLE__)
+# if !(__FreeBSD_version >= 50200)
+#  undef USE_ALLOCA
+# endif
+#endif
+
+#ifdef USE_ALLOCA
+#define CAUDIUM_ALLOCA(_size_) alloca((_size_))
+#define CAUDIUM_UNALLOCA(_ptr_) 
+#else
+#define CAUDIUM_ALLOCA(_size_) malloc((_size_))
+#define CAUDIUM_UNALLOCA(_ptr_) if ((_ptr_)) free((_ptr_))
+#endif
+
+#define CAUDIUM_PTR_VALID(_ptr_) if (!(_ptr_)) Pike_error("Out of memory\n")
